/*
 *  DisplayPages.h - Definition of the seven display pages
 *  which make up this application.
 *
 *  Concept, Design and Implementation by: Craig A. Lindley
 *  Last Update: 10/30/2015
 */

#ifndef DISPLAYPAGES_H
#define DISPLAYPAGES_H

#include "Icons.h"
#include "NTP.h"
#include "Weather.h"

extern ESP8266_ST7735 lcd;
extern Weather weather;

// ***************************************************************
//                    Start Display Page One
// ***************************************************************
#define CREDITS_STRING_1 "Esp8266 Weather Clock"
#define CREDITS_STRING_2 "Craig A. Lindley"
#define CREDITS_STRING_3 "Weather data courtesy of"
#define CREDITS_STRING_4 "myweather2.com"

// Draw the page one display - Wifi login/credits
void drawDisplayPageOne() {

  // Draw credits on display
  drawCenteredText(10, 1, CREDITS_STRING_1, COLOR_RED);
  drawCenteredText(22, 1, CREDITS_STRING_2, COLOR_BLACK);
  drawCenteredText(84, 1, CREDITS_STRING_3, COLOR_RED);
  drawCenteredText(96, 1, CREDITS_STRING_4, COLOR_RED);

  // Position the WiFi logo icon horizontally centered on the display
  int xOffset = (lcd.width()  - WIFI_ICON_WIDTH)  / 2;
  int yOffset = (lcd.height() - WIFI_ICON_HEIGHT) / 2;

  // Move up a little from vertical center
  yOffset -= 7;

  // Draw the WiFi icon
  lcd.drawXBitmap(xOffset, yOffset, WiFiIcon, WIFI_ICON_WIDTH, WIFI_ICON_HEIGHT, COLOR_BLUE);

  // Draw the page indicator
  drawPageIndicator(0, COLOR_BLUE);
}
// ***************************************************************
//                    End Display Page One
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Two
// ***************************************************************
// Draw the page two display - Current conditions
void drawDisplayPageTwo() {

  drawCenteredText(  8, 1, "- Current Conditions -",                COLOR_RED);
  drawCenteredText( 20, 1, weather.getCurrentHumidityString(),      COLOR_BLACK);
  drawCenteredText( 32, 1, weather.getCurrentPressureString(),      COLOR_BLACK);
  drawCenteredText( 44, 1, weather.getCurrentWeatherTextString(),   COLOR_RED);
  drawCenteredText( 90, 1, weather.getCurrentWindDirectionString(), COLOR_BLACK);
  drawCenteredText(102, 1, weather.getCurrentWindSpeedString(),     COLOR_BLACK);

  drawCenteredText(63, 2, weather.getCurrentTemperatureString(),    COLOR_RED);

  // Draw the page indicator
  drawPageIndicator(1, COLOR_RED);
}
// ***************************************************************
//                    End Display Page Two
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Three
// ***************************************************************
// Draw the page three display - Day forecast
void drawDisplayPageThree() {

  drawCenteredText(  8, 1, "- Day Forecast -",                           COLOR_RED);
  drawCenteredText( 25, 1, weather.getForecastDay1DateString(),          COLOR_BLACK);
  drawCenteredText( 37, 1, weather.getForecastDay1WeatherTextString(),   COLOR_RED);
  drawCenteredText( 88, 1, weather.getForecastDay1WindDirectionString(), COLOR_BLACK);
  drawCenteredText(101, 1, weather.getForecastDay1WindSpeedString(),     COLOR_BLACK);

  drawCenteredText(59, 2, weather.getForecastDay1MaxTemperatureString(), COLOR_RED);

  // Draw the page indicator
  drawPageIndicator(2, COLOR_GREEN);
}
// ***************************************************************
//                    End Display Page Three
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Four
// ***************************************************************
// Draw the page four display - Night forecast
void drawDisplayPageFour() {

  drawCenteredText(  8, 1, "- Night Forecast -",                           COLOR_RED);
  drawCenteredText( 25, 1, weather.getForecastDay1DateString(),            COLOR_BLACK);
  drawCenteredText( 37, 1, weather.getForecastNight1WeatherTextString(),   COLOR_RED);
  drawCenteredText( 88, 1, weather.getForecastNight1WindDirectionString(), COLOR_BLACK);
  drawCenteredText(101, 1, weather.getForecastNight1WindSpeedString(),     COLOR_BLACK);

  drawCenteredText(59, 2, weather.getForecastNight1MinTemperatureString(), COLOR_RED);

  // Draw the page indicator
  drawPageIndicator(3, COLOR_BLACK);
}
// ***************************************************************
//                    End Display Page Four
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Five
// ***************************************************************
// Draw the page five display - Next day forecast
void drawDisplayPageFive() {

  drawCenteredText(  8, 1, "- Next Day Forecast -",                      COLOR_RED);
  drawCenteredText( 25, 1, weather.getForecastDay2DateString(),          COLOR_BLACK);
  drawCenteredText( 37, 1, weather.getForecastDay2WeatherTextString(),   COLOR_RED);
  drawCenteredText( 88, 1, weather.getForecastDay2WindDirectionString(), COLOR_BLACK);
  drawCenteredText(101, 1, weather.getForecastDay2WindSpeedString(),     COLOR_BLACK);

  drawCenteredText(59, 2, weather.getForecastDay2MaxTemperatureString(), COLOR_RED);

  // Draw the page indicator
  drawPageIndicator(4, COLOR_GREEN);
}
// ***************************************************************
//                    End Display Page Five
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Six
// ***************************************************************
// Draw the page six display - Next night forecast
void drawDisplayPageSix() {

  drawCenteredText(  8, 1, "- Next Night Forecast -",                      COLOR_RED);
  drawCenteredText( 25, 1, weather.getForecastDay2DateString(),            COLOR_BLACK);
  drawCenteredText( 37, 1, weather.getForecastNight2WeatherTextString(),   COLOR_RED);
  drawCenteredText( 88, 1, weather.getForecastNight2WindDirectionString(), COLOR_BLACK);
  drawCenteredText(101, 1, weather.getForecastNight2WindSpeedString(),     COLOR_BLACK);

  drawCenteredText(59, 2, weather.getForecastNight2MinTemperatureString(), COLOR_RED);

  // Draw the page indicator
  drawPageIndicator(5, COLOR_RED);
}
// ***************************************************************
//                    End Display Page Six
// ***************************************************************

// ***************************************************************
//                    Begin Display Page Seven
// ***************************************************************
// Draw the page seven display - NTP Clock
void drawDisplayPageSeven() {

  const char *dstStr = getDSTStr();

  // Draw centered day of week string
  drawCenteredText(18, 2, getDWStr(), COLOR_RED);

  // Conditionally display daylight saving time indicator
  if ((dstStr != NULL) && (strlen(dstStr) != 0)) {
    drawText(117, 23, 1, dstStr, COLOR_BLACK);
  }
  // Draw centered date string
  drawCenteredText(52, 2, getDateStr(), COLOR_RED);

  // Draw centered time string
  drawCenteredText(75, 3, getTimeStr(), COLOR_RED);

  // Draw centered title string
  drawCenteredText(104, 1, "Esp8266 NTP Clock", COLOR_BLUE);

  // Draw an Icon
  if (isDayTime()) {
    lcd.drawXBitmap(0, 0, sunIcon,  NORMAL_ICON_WIDTH, NORMAL_ICON_HEIGHT, COLOR_BLACK);
  } else  {
    lcd.drawXBitmap(0, 0, moonIcon, NORMAL_ICON_WIDTH, NORMAL_ICON_HEIGHT, COLOR_BLACK);
  }

  // Draw the page indicator
  drawPageIndicator(6, COLOR_BLUE);
}
// ***************************************************************
//                    End Display Page Seven
// ***************************************************************

#endif

