/*
 *  TGFunctions.h - Text and Graphics Support Functions
 *
 *  Concept, Design and Implementation by: Craig A. Lindley
 *  Last Update: 10/30/2015
 */

#ifndef TGFUNCTIONS_H
#define TGFUNCTIONS_H

extern ESP8266_ST7735 lcd;

#include "Icons.h"

// Clear the display
void clearDisplay() {
  // Set all pixels to white
  lcd.fillScreen(COLOR_WHITE);
}

// Get the width in pixels of a text string of specified size
int getTextWidth(const char *text, int size) {
  int len = strlen(text);

  // Chars are 5 px wide with 1 px space = 6
  return 6 * len * size;
}

// Calculate the x offset necessary to center a text string of specified size
int xOffsetForCenteredText(const char *text, int size) {
  return (lcd.width() - getTextWidth(text, size)) / 2;
}

// Draw a text string at specified location with specified size and color
void drawText(int x, int y, int size, const char *text, uint16_t color) {
  lcd.setCursor(x, y);
  lcd.setTextSize(size);
  lcd.setTextColor(color);
  lcd.print(text);
}

// Draw a text string of specified size and color centered on display with y position
void drawCenteredText(int y, int size, const char *text, uint16_t color) {
  drawText(xOffsetForCenteredText(text, size), y, size, text, color);
}

// Draw display frame
void drawDisplayFrame() {
  // Draw frame around display
  lcd.drawRect(0, 0, lcd.width(),      lcd.height(),     COLOR_BLUE);
  lcd.drawRect(1, 1, lcd.width() - 2 , lcd.height() - 2, COLOR_RED);
  lcd.drawRect(2, 2, lcd.width() - 4 , lcd.height() - 4, COLOR_BLUE);
}

#define NUMBER_OF_DISPLAY_PAGES 7
#define CIRCLE_SPACE_PX        12
#define CIRCLE_RADIUS           3
#define INDICATOR_Y_OFFSET    118

void drawPageIndicator(int pageNumber, uint16_t color) {

  int xCenter = lcd.width() / 2;
  int x;
  int spaceIncrement = 3;

  for (int i = 0; i < NUMBER_OF_DISPLAY_PAGES; i++) {
    x = xCenter - (spaceIncrement-- * CIRCLE_SPACE_PX);
    if (i == pageNumber) {
      lcd.fillCircle(x, INDICATOR_Y_OFFSET, CIRCLE_RADIUS, color);
    } else  {
      lcd.drawCircle(x, INDICATOR_Y_OFFSET, CIRCLE_RADIUS, COLOR_BLACK);
    }
  }
}

#endif

