/*
 *  Weather.h - Weather Class Definition
 *
 *  This class streams the weather data from the Internet,
 *  parses the JSON that is returned and extracts the pertinent
 *  weather attributes used by this program.
 *
 *  Concept, Design and Implementation by: Craig A. Lindley
 *  Last Update: 10/30/2015
 */

#ifndef WEATHER_H
#define WEATHER_H

#include <ArduinoJson.h>
#include <ESP8266WiFi.h>

#define STRING_LENGTH      20
#define LONG_STRING_LENGTH 50

class Weather {

  public:
    // Class constructor
    Weather(const char *_apiKey, const char *_locationString);

    // Retrieve the weather data from data provider
    bool retrieveWeatherData();

    // Functions for retrieving weather data attributes
    const char *getCurrentHumidityString();
    const char *getCurrentPressureString();
    const char *getCurrentTemperatureString();
    const char *getCurrentWeatherCodeString();
    const char *getCurrentWeatherTextString();
    const char *getCurrentWindDirectionString();
    const char *getCurrentWindSpeedString();

    const char *getForecastDay1DateString();
    const char *getForecastDay1WeatherCodeString();
    const char *getForecastDay1WeatherTextString();
    const char *getForecastDay1WindDirectionString();
    const char *getForecastDay1WindSpeedString();
    const char *getForecastDay1MaxTemperatureString();

    const char *getForecastNight1WeatherCodeString();
    const char *getForecastNight1WeatherTextString();
    const char *getForecastNight1WindDirectionString();
    const char *getForecastNight1WindSpeedString();
    const char *getForecastNight1MinTemperatureString();

    const char *getForecastDay2DateString();
    const char *getForecastDay2WeatherCodeString();
    const char *getForecastDay2WeatherTextString();
    const char *getForecastDay2WindDirectionString();
    const char *getForecastDay2WindSpeedString();
    const char *getForecastDay2MaxTemperatureString();

    const char *getForecastNight2WeatherCodeString();
    const char *getForecastNight2WeatherTextString();
    const char *getForecastNight2WindDirectionString();
    const char *getForecastNight2WindSpeedString();
    const char *getForecastNight2MinTemperatureString();

  private:
    static const int JSON_BUFFER_SIZE = 1600;
    char buffer[JSON_BUFFER_SIZE];

    static const int FORMAT_BUFFER_SIZE = 20;
    char formatBuffer[FORMAT_BUFFER_SIZE];

    const char *apiKey;
    const char *locationString;

    WiFiClient client;

    char humidity[STRING_LENGTH];
    char pressure[STRING_LENGTH];
    char temperature[STRING_LENGTH];
    char weatherCode[STRING_LENGTH];
    char weatherText[LONG_STRING_LENGTH];
    char windDirection[STRING_LENGTH];
    char windSpeed[STRING_LENGTH];

    char forecastDay1Date[STRING_LENGTH];
    char forecastDay1WeatherCode[STRING_LENGTH];
    char forecastDay1WeatherText[LONG_STRING_LENGTH];
    char forecastDay1WindDirection[STRING_LENGTH];
    char forecastDay1WindSpeed[STRING_LENGTH];
    char forecastDay1MaxTemperature[STRING_LENGTH];

    char forecastNight1Date[STRING_LENGTH];
    char forecastNight1WeatherCode[STRING_LENGTH];
    char forecastNight1WeatherText[LONG_STRING_LENGTH];
    char forecastNight1WindDirection[STRING_LENGTH];
    char forecastNight1WindSpeed[STRING_LENGTH];
    char forecastNight1MinTemperature[STRING_LENGTH];

    char forecastDay2Date[STRING_LENGTH];
    char forecastDay2WeatherCode[STRING_LENGTH];
    char forecastDay2WeatherText[LONG_STRING_LENGTH];
    char forecastDay2WindDirection[STRING_LENGTH];
    char forecastDay2WindSpeed[STRING_LENGTH];
    char forecastDay2MaxTemperature[STRING_LENGTH];

    char forecastNight2Date[STRING_LENGTH];
    char forecastNight2WeatherCode[STRING_LENGTH];
    char forecastNight2WeatherText[LONG_STRING_LENGTH];
    char forecastNight2WindDirection[STRING_LENGTH];
    char forecastNight2WindSpeed[STRING_LENGTH];
    char forecastNight2MinTemperature[STRING_LENGTH];
};

#endif

